'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var hotkeys = require('hotkeys-js');
var mobx = require('mobx');
var jsxRuntime = require('react/jsx-runtime');
var antd = require('antd');
var mobxReact = require('mobx-react');
var reactIntl = require('react-intl');
var icons = require('@ant-design/icons');
var dayjs$1 = require('dayjs');
var weekday = require('dayjs/plugin/weekday');
var localeData = require('dayjs/plugin/localeData');
var weekOfYear = require('dayjs/plugin/weekOfYear');
var weekYear = require('dayjs/plugin/weekYear');
var advancedFormat = require('dayjs/plugin/advancedFormat');
var customParseFormat = require('dayjs/plugin/customParseFormat');
var generatePicker = require('antd/es/date-picker/generatePicker');
require('antd/es/date-picker/style/css');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var hotkeys__default = /*#__PURE__*/_interopDefaultLegacy(hotkeys);
var dayjs__default = /*#__PURE__*/_interopDefaultLegacy(dayjs$1);
var weekday__default = /*#__PURE__*/_interopDefaultLegacy(weekday);
var localeData__default = /*#__PURE__*/_interopDefaultLegacy(localeData);
var weekOfYear__default = /*#__PURE__*/_interopDefaultLegacy(weekOfYear);
var weekYear__default = /*#__PURE__*/_interopDefaultLegacy(weekYear);
var advancedFormat__default = /*#__PURE__*/_interopDefaultLegacy(advancedFormat);
var customParseFormat__default = /*#__PURE__*/_interopDefaultLegacy(customParseFormat);
var generatePicker__default = /*#__PURE__*/_interopDefaultLegacy(generatePicker);

/**
 * A simple, zero-dependency function for creating random strings.
 * You may prefer to use UUID v4 instead.
 */
function generateKey() {
    return String(window.crypto.getRandomValues(new Uint32Array(1))[0]);
}

/**
 * This function tries its best to guess the display name for the entity instance.
 * You will likely want to replace the call to this function with your own implementation.
 *
 * @param entityInstance
 */
function guessDisplayName(entityInstance) {
    if (entityInstance == null) {
        return '';
    }
    if ('name' in entityInstance) {
        return String(entityInstance.name);
    }
    if ('title' in entityInstance) {
        return String(entityInstance.title);
    }
    if ('caption' in entityInstance) {
        return String(entityInstance.caption);
    }
    if ('label' in entityInstance) {
        return String(entityInstance.label);
    }
    if ('summary' in entityInstance) {
        return String(entityInstance.summary);
    }
    if ('description' in entityInstance) {
        return String(entityInstance.description);
    }
    if ('firstName' in entityInstance && 'lastName' in entityInstance) {
        return String(`${entityInstance.firstName} ${entityInstance.lastName}`);
    }
    if ('firstName' in entityInstance) {
        return String(entityInstance.firstName);
    }
    if ('lastName' in entityInstance) {
        return String(entityInstance.lastName);
    }
    if ('id' in entityInstance) {
        return String(entityInstance.id);
    }
    return JSON.stringify(entityInstance);
}

function guessLabel(propertyName) {
    const split = propertyName.replace(/([^A-Z])([A-Z])/g, '$1 $2');
    return split[0].toUpperCase() + split.slice(1);
}

class EventEmitter {
    constructor() {
        this.logEmits = false;
        this.listeners = new Map();
    }
    emit(eventName, ...restParams) {
        const events = this.listeners.get(eventName);
        if (events) {
            events.forEach((fn) => {
                fn.call(null, ...restParams);
            });
        }
    }
    on(eventName, fn) {
        if (!this.listeners.get(eventName)) {
            this.listeners.set(eventName, new Set());
        }
        const events = this.listeners.get(eventName);
        events === null || events === void 0 ? void 0 : events.add(fn);
        // or use unsubscribe function
        return () => {
            this.off(eventName, fn);
        };
    }
    once(eventName, fn) {
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        const unsubscribe = this.on(eventName, (...args) => {
            fn(...args);
            unsubscribe();
        });
        return unsubscribe;
    }
    off(eventName, fn) {
        const events = this.listeners.get(eventName);
        if (events)
            events.delete(fn);
    }
}

/**
 * Remove all attributes with name listed in sortOutFields from fieldValues recursively.
 *
 * @param fieldValues object to be filtered
 * @param sortOutFields fields to be removed from filtered object
 */
function filterFieldValues(fieldValues, sortOutFields) {
    return removeProperties(fieldValues, sortOutFields);
}
function removeProperties(obj, sortOutFields) {
    if (Object(obj) !== obj) {
        return obj;
    }
    if (Array.isArray(obj)) {
        return obj.map(o => removeProperties(o, sortOutFields));
    }
    return Object.fromEntries(Object.entries(obj)
        .filter(([key]) => !sortOutFields.includes(key))
        .map(([key, value]) => ([key, removeProperties(value, sortOutFields)])));
}

class HotkeyStore {
    constructor(defaultHotkeyConfigs) {
        // initialized with creating store
        this.defaultHotkeyConfigs = [];
        // currently registered hotkeyConfigs in runtime
        this.dynamicHotkeyConfigs = [];
        this.addHotkeyConfig = (hotkeyConfig) => {
            this.dynamicHotkeyConfigs.push(hotkeyConfig);
        };
        this.removeHotkeyConfigs = (hotkeyConfig) => {
            const filtredDynamicHotkeyConfigs = this.dynamicHotkeyConfigs.filter(hotkeyConfigItem => !equalsHotkeyConfig(hotkeyConfig, hotkeyConfigItem));
            this.dynamicHotkeyConfigs = filtredDynamicHotkeyConfigs;
        };
        mobx.makeObservable(this, {
            dynamicHotkeyConfigs: mobx.observable,
            addHotkeyConfig: mobx.action,
            removeHotkeyConfigs: mobx.action,
            hotkeyConfigs: mobx.computed,
        });
        this.defaultHotkeyConfigs = defaultHotkeyConfigs;
    }
    // merged version of defaultHotkeyConfigs and dynamicHotkeyConfigs
    get hotkeyConfigs() {
        const onlyInDynamicHotkeyConfigs = this.dynamicHotkeyConfigs.filter(dynamicHotkeyConfig => !this.defaultHotkeyConfigs.some(defaultHotkeyConfig => equalsHotkeyConfig(defaultHotkeyConfig, dynamicHotkeyConfig)));
        const redefinedDefaultHotkeyConfigs = this.defaultHotkeyConfigs
            .map(defaultHotkeyConfig => this.dynamicHotkeyConfigs.find(dynamicHotkeyConfig => equalsHotkeyConfig(defaultHotkeyConfig, dynamicHotkeyConfig)) || defaultHotkeyConfig);
        const hotkeyConfigs = [...redefinedDefaultHotkeyConfigs, ...onlyInDynamicHotkeyConfigs];
        return hotkeyConfigs;
    }
}
function equalsHotkeyConfig(hotkeyConfigOne, hotkeyConfigTwo) {
    return hotkeyConfigOne.description === hotkeyConfigTwo.description;
}

const HotkeyContext = React.createContext(new HotkeyStore([]));
function useHotkeyStore() {
    return React.useContext(HotkeyContext);
}

const useHotkey = (hotkeyConfig, memoizedCallback) => {
    const { addHotkeyConfig, removeHotkeyConfigs } = useHotkeyStore();
    React.useEffect(() => {
        addHotkeyConfig(hotkeyConfig);
        hotkeys__default["default"](hotkeyConfig.hotkey, memoizedCallback);
        return () => {
            hotkeys__default["default"].unbind(hotkeyConfig.hotkey, memoizedCallback);
            removeHotkeyConfigs(hotkeyConfig);
        };
    }, [
        hotkeyConfig,
        addHotkeyConfig,
        removeHotkeyConfigs,
        memoizedCallback,
    ]);
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const useScreenHotkey = (_x, _y) => {
    return null;
}; // TODO
// export const useScreenHotkey = (
//   hotkeyConfig: HotkeyConfig,
//   memoizedCallback: KeyHandler,
// ) => {
//   const {addHotkeyConfig, removeHotkeyConfigs} = useHotkeyStore();
//   // const {activeTab, activeBreadcrumb} = useScreens();
//   // const screenMeta = useScreenMeta();
//
//   useEffect(() => {
//     if (
//       screenMeta != null
//       && activeTab?.key === screenMeta.tab.key
//       && activeBreadcrumb?.key === screenMeta.breadcrumb.key
//     ) {
//       hotkeys(hotkeyConfig.hotkey, memoizedCallback);
//       addHotkeyConfig(hotkeyConfig);
//     }
//
//     return () => {
//       if (activeTab?.key === screenMeta?.tab.key && activeBreadcrumb?.key === screenMeta?.breadcrumb.key) {
//         hotkeys.unbind(hotkeyConfig.hotkey, memoizedCallback);
//         removeHotkeyConfigs(hotkeyConfig);
//       }
//     };
//   }, [activeTab?.key, activeBreadcrumb?.key, hotkeyConfig, addHotkeyConfig, removeHotkeyConfigs, memoizedCallback, screenMeta, screenMeta?.tab.key, screenMeta?.breadcrumb.key]);
// }

const BROWSER_HOTKEYS_CATEGORY_NAME = 'hotkeys.category.browser';
const createEntityHotkeyConfig = {
    hotkey: 'g+c',
    description: 'hotkeys.browser.createEntity',
    categoryName: BROWSER_HOTKEYS_CATEGORY_NAME,
};
const browserHotkeysConfigs = [
    createEntityHotkeyConfig,
];
const useDefaultBrowserHotkeys = ({ openEditor }) => {
    React.useCallback(() => openEditor(), [openEditor]);
};

const EDITOR_HOTKEYS_CATEGORY_NAME = 'hotkeys.category.editor';
const saveEntityHotkeysConfig = {
    hotkey: 's',
    description: 'hotkeys.editor.saveEntity',
    categoryName: EDITOR_HOTKEYS_CATEGORY_NAME,
};
const editorHotkeysConfigs = [
    saveEntityHotkeysConfig,
];
const useDefaultEditorHotkeys = ({ saveEntity }) => {
};

function groupBy(configs, propName) {
    return configs.reduce((acc, el) => {
        const propValue = el[propName];
        if (acc[propValue] == null) {
            acc[propValue] = [];
        }
        acc[propValue].push(el);
        return acc;
    }, {});
}
const HotkeyInfo = mobxReact.observer(({ hotkeyConfigs }) => {
    const intl = reactIntl.useIntl();
    const hotkeysConfigByCategory = groupBy(hotkeyConfigs, 'categoryName');
    return (jsxRuntime.jsx("div", { children: Object.entries(hotkeysConfigByCategory)
            .map(([category, categoryHotkeysConfig]) => (jsxRuntime.jsx(antd.Descriptions, Object.assign({ title: intl.formatMessage({ id: category }), column: 1 }, { children: categoryHotkeysConfig
                .map(hotkeyConfig => jsxRuntime.jsx(antd.Descriptions.Item, Object.assign({ label: hotkeyConfig.hotkey }, { children: intl.formatMessage({ id: hotkeyConfig.description }) }), hotkeyConfig.description)) }), category))) }, void 0));
});

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".ant-btn-text.hotkeyInfoButton__iconBtn {\n  color: #CCCCCC;\n}\n\n.ant-btn-text.hotkeyInfoButton__iconBtn:hover {\n  color: #FFF;\n}\n\n.ant-btn-text.hotkeyInfoButton__iconBtn:focus {\n  color: #FFF;\n}\n\n.ant-btn-text.hotkeyInfoButton__scrollContainer {\n  max-height: 400px;\n  overflow-y: auto;\n}";
styleInject(css_248z);

const HotkeyInfoModalButton = mobxReact.observer(({ visible, setVisible, }) => {
    const intl = reactIntl.useIntl();
    const { hotkeyConfigs } = useHotkeyStore();
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(antd.Button, { type: "text", className: "hotkeyInfoButton__iconBtn", icon: jsxRuntime.jsx(icons.MacCommandOutlined, {}, void 0), onClick: () => setVisible(true) }, void 0), jsxRuntime.jsx(antd.Modal, Object.assign({ visible: visible, title: intl.formatMessage({ id: "hotkeys.hotkeyInfo.title" }), footer: null, onCancel: () => setVisible(false) }, { children: jsxRuntime.jsx("div", Object.assign({ className: "hotkeyInfoButton__scrollContainer" }, { children: jsxRuntime.jsx(HotkeyInfo, { hotkeyConfigs: hotkeyConfigs }, void 0) }), void 0) }), void 0)] }, void 0));
});

class MenuStore {
    constructor() {
        this._addonItems = [];
        mobx.makeObservable(this, {
            _addonItems: mobx.observable,
            addAddonItem: mobx.action,
            addonMenuItems: mobx.computed
        });
    }
    addAddonItem(itemInfo) {
        this._addonItems.push(itemInfo);
    }
    get addonMenuItems() {
        return this._addonItems;
    }
}
const menuStore = new MenuStore();

class I18nStore {
    constructor(localeConfigOptions, defaultLocale) {
        this.localeConfigs = {};
        this.mergeMessages = (locale, messages) => {
            const localeInfo = this.localeConfigs[locale];
            if (localeInfo != null) {
                localeInfo.messages = Object.assign(Object.assign({}, localeInfo.messages), messages);
            }
        };
        this.setCurrentLocale = (locale) => {
            if (!Object.keys(this.localeConfigs).includes(locale)) {
                throw new Error(`LocaleConfig should contain ${locale} locale`);
            }
            this.currentLocale = locale;
        };
        this.setLocaleConfigs(localeConfigOptions);
        if (!Object.keys(localeConfigOptions).includes(defaultLocale)) {
            throw new Error(`LocaleConfigOptions should contain ${defaultLocale} defaultLocale`);
        }
        this.storage = window.localStorage;
        const previouslySavedLocale = this.storage.getItem(I18nStore.LOCALE_STORAGE_KEY);
        if (previouslySavedLocale != null && Object.keys(this.localeConfigs).includes(previouslySavedLocale)) {
            this.currentLocale = previouslySavedLocale;
        }
        else {
            console.warn(`Locale ${previouslySavedLocale} saved in local storage is not present in localeConfigs. Defaulting to ${defaultLocale} locale`);
            this.currentLocale = defaultLocale;
        }
        mobx.makeObservable(this, {
            localeConfigs: mobx.observable,
            currentLocale: mobx.observable,
            mergeMessages: mobx.action,
            setCurrentLocale: mobx.action,
            currentMessages: mobx.computed,
        });
        mobx.autorun(() => {
            if (this.currentLocale != null) {
                this.storage.setItem(I18nStore.LOCALE_STORAGE_KEY, this.currentLocale);
            }
            else {
                this.storage.removeItem(I18nStore.LOCALE_STORAGE_KEY);
            }
        });
    }
    setLocaleConfigs(localeConfigOptions) {
        this.localeConfigs = Object.entries(localeConfigOptions)
            .reduce((newLocalesInfo, [locale, localeConfigOption]) => {
            var _a, _b;
            newLocalesInfo[locale] = Object.assign(Object.assign({}, localeConfigOption), { messages: (_a = localeConfigOption.messages) !== null && _a !== void 0 ? _a : {}, direction: (_b = localeConfigOption.direction) !== null && _b !== void 0 ? _b : 'ltr' });
            return newLocalesInfo;
        }, {});
    }
    get currentMessages() {
        return this.localeConfigs[this.currentLocale].messages;
    }
}
I18nStore.LOCALE_STORAGE_KEY = 'amplicodeLocale';

const I18nStoreContext = React.createContext(new I18nStore({ en: { caption: "English", antdLocale: { locale: 'en' } } }, 'en'));
const useI18nStore = () => React.useContext(I18nStoreContext);
function I18nStoreProvider({ store, defaultLocale, localeConfigs, children }) {
    const [i18nStore] = React.useState(() => store !== null && store !== void 0 ? store : new I18nStore(localeConfigs, defaultLocale));
    return jsxRuntime.jsx(I18nStoreContext.Provider, Object.assign({ value: i18nStore }, { children: children }), void 0);
}

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var interopRequireDefault = createCommonjsModule(function (module) {
function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {
    "default": obj
  };
}

module.exports = _interopRequireDefault, module.exports.__esModule = true, module.exports["default"] = module.exports;
});

unwrapExports(interopRequireDefault);

var warning_1 = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.call = call;
exports.default = void 0;
exports.note = note;
exports.noteOnce = noteOnce;
exports.resetWarned = resetWarned;
exports.warning = warning;
exports.warningOnce = warningOnce;

/* eslint-disable no-console */
var warned = {};

function warning(valid, message) {
  // Support uglify
  if (process.env.NODE_ENV !== 'production' && !valid && console !== undefined) {
    console.error("Warning: ".concat(message));
  }
}

function note(valid, message) {
  // Support uglify
  if (process.env.NODE_ENV !== 'production' && !valid && console !== undefined) {
    console.warn("Note: ".concat(message));
  }
}

function resetWarned() {
  warned = {};
}

function call(method, valid, message) {
  if (!valid && !warned[message]) {
    method(false, message);
    warned[message] = true;
  }
}

function warningOnce(valid, message) {
  call(warning, valid, message);
}

function noteOnce(valid, message) {
  call(note, valid, message);
}

var _default = warningOnce;
/* eslint-enable */

exports.default = _default;
});

unwrapExports(warning_1);
warning_1.call;
warning_1.note;
warning_1.noteOnce;
warning_1.resetWarned;
warning_1.warning;
warning_1.warningOnce;

var dayjs = createCommonjsModule(function (module, exports) {



Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _dayjs = interopRequireDefault(dayjs__default["default"]);



var _weekday = interopRequireDefault(weekday__default["default"]);

var _localeData = interopRequireDefault(localeData__default["default"]);

var _weekOfYear = interopRequireDefault(weekOfYear__default["default"]);

var _weekYear = interopRequireDefault(weekYear__default["default"]);

var _advancedFormat = interopRequireDefault(advancedFormat__default["default"]);

var _customParseFormat = interopRequireDefault(customParseFormat__default["default"]);

_dayjs.default.extend(_customParseFormat.default);

_dayjs.default.extend(_advancedFormat.default);

_dayjs.default.extend(_weekday.default);

_dayjs.default.extend(_localeData.default);

_dayjs.default.extend(_weekOfYear.default);

_dayjs.default.extend(_weekYear.default);

_dayjs.default.extend(function (o, c) {
  // todo support Wo (ISO week)
  var proto = c.prototype;
  var oldFormat = proto.format;

  proto.format = function f(formatStr) {
    var str = (formatStr || '').replace('Wo', 'wo');
    return oldFormat.bind(this)(str);
  };
});

var localeMap = {
  // ar_EG:
  // az_AZ:
  // bg_BG:
  bn_BD: 'bn-bd',
  by_BY: 'be',
  // ca_ES:
  // cs_CZ:
  // da_DK:
  // de_DE:
  // el_GR:
  en_GB: 'en-gb',
  en_US: 'en',
  // es_ES:
  // et_EE:
  // fa_IR:
  // fi_FI:
  fr_BE: 'fr',
  fr_CA: 'fr-ca',
  // fr_FR:
  // ga_IE:
  // gl_ES:
  // he_IL:
  // hi_IN:
  // hr_HR:
  // hu_HU:
  hy_AM: 'hy-am',
  // id_ID:
  // is_IS:
  // it_IT:
  // ja_JP:
  // ka_GE:
  // kk_KZ:
  // km_KH:
  kmr_IQ: 'ku',
  // kn_IN:
  // ko_KR:
  // ku_IQ: // previous ku in antd
  // lt_LT:
  // lv_LV:
  // mk_MK:
  // ml_IN:
  // mn_MN:
  // ms_MY:
  // nb_NO:
  // ne_NP:
  nl_BE: 'nl-be',
  // nl_NL:
  // pl_PL:
  pt_BR: 'pt-br',
  // pt_PT:
  // ro_RO:
  // ru_RU:
  // sk_SK:
  // sl_SI:
  // sr_RS:
  // sv_SE:
  // ta_IN:
  // th_TH:
  // tr_TR:
  // uk_UA:
  // ur_PK:
  // vi_VN:
  zh_CN: 'zh-cn',
  zh_HK: 'zh-hk',
  zh_TW: 'zh-tw'
};

var parseLocale = function parseLocale(locale) {
  var mapLocale = localeMap[locale];
  return mapLocale || locale.split('_')[0];
};

var parseNoMatchNotice = function parseNoMatchNotice() {
  /* istanbul ignore next */
  (0, warning_1.noteOnce)(false, 'Not match any format. Please help to fire a issue about this.');
};

var generateConfig = {
  // get
  getNow: function getNow() {
    return (0, _dayjs.default)();
  },
  getFixedDate: function getFixedDate(string) {
    return (0, _dayjs.default)(string, ['YYYY-M-DD', 'YYYY-MM-DD']);
  },
  getEndDate: function getEndDate(date) {
    return date.endOf('month');
  },
  getWeekDay: function getWeekDay(date) {
    var clone = date.locale('en');
    return clone.weekday() + clone.localeData().firstDayOfWeek();
  },
  getYear: function getYear(date) {
    return date.year();
  },
  getMonth: function getMonth(date) {
    return date.month();
  },
  getDate: function getDate(date) {
    return date.date();
  },
  getHour: function getHour(date) {
    return date.hour();
  },
  getMinute: function getMinute(date) {
    return date.minute();
  },
  getSecond: function getSecond(date) {
    return date.second();
  },
  // set
  addYear: function addYear(date, diff) {
    return date.add(diff, 'year');
  },
  addMonth: function addMonth(date, diff) {
    return date.add(diff, 'month');
  },
  addDate: function addDate(date, diff) {
    return date.add(diff, 'day');
  },
  setYear: function setYear(date, year) {
    return date.year(year);
  },
  setMonth: function setMonth(date, month) {
    return date.month(month);
  },
  setDate: function setDate(date, num) {
    return date.date(num);
  },
  setHour: function setHour(date, hour) {
    return date.hour(hour);
  },
  setMinute: function setMinute(date, minute) {
    return date.minute(minute);
  },
  setSecond: function setSecond(date, second) {
    return date.second(second);
  },
  // Compare
  isAfter: function isAfter(date1, date2) {
    return date1.isAfter(date2);
  },
  isValidate: function isValidate(date) {
    return date.isValid();
  },
  locale: {
    getWeekFirstDay: function getWeekFirstDay(locale) {
      return (0, _dayjs.default)().locale(parseLocale(locale)).localeData().firstDayOfWeek();
    },
    getWeekFirstDate: function getWeekFirstDate(locale, date) {
      return date.locale(parseLocale(locale)).weekday(0);
    },
    getWeek: function getWeek(locale, date) {
      return date.locale(parseLocale(locale)).week();
    },
    getShortWeekDays: function getShortWeekDays(locale) {
      return (0, _dayjs.default)().locale(parseLocale(locale)).localeData().weekdaysMin();
    },
    getShortMonths: function getShortMonths(locale) {
      return (0, _dayjs.default)().locale(parseLocale(locale)).localeData().monthsShort();
    },
    format: function format(locale, date, _format) {
      return date.locale(parseLocale(locale)).format(_format);
    },
    parse: function parse(locale, text, formats) {
      var localeStr = parseLocale(locale);

      for (var i = 0; i < formats.length; i += 1) {
        var format = formats[i];
        var formatText = text;

        if (format.includes('wo') || format.includes('Wo')) {
          // parse Wo
          var year = formatText.split('-')[0];
          var weekStr = formatText.split('-')[1];
          var firstWeek = (0, _dayjs.default)(year, 'YYYY').startOf('year').locale(localeStr);

          for (var j = 0; j <= 52; j += 1) {
            var nextWeek = firstWeek.add(j, 'week');

            if (nextWeek.format('Wo') === weekStr) {
              return nextWeek;
            }
          }

          parseNoMatchNotice();
          return null;
        }

        var date = (0, _dayjs.default)(formatText, format).locale(localeStr);

        if (date.isValid()) {
          return date;
        }
      }

      if (text) {
        parseNoMatchNotice();
      }

      return null;
    }
  }
};
var _default = generateConfig;
exports.default = _default;
});

var dayjsGenerateConfig = unwrapExports(dayjs);

const DatePicker = generatePicker__default["default"](dayjsGenerateConfig);

const TimePicker = React__default["default"].forwardRef((props, ref) => {
    return jsxRuntime.jsx(DatePicker, Object.assign({}, props, { picker: "time", mode: undefined, ref: ref }), void 0);
});
TimePicker.displayName = "TimePicker";

exports.DatePicker = DatePicker;
exports.EventEmitter = EventEmitter;
exports.HotkeyContext = HotkeyContext;
exports.HotkeyInfo = HotkeyInfo;
exports.HotkeyInfoModalButton = HotkeyInfoModalButton;
exports.HotkeyStore = HotkeyStore;
exports.I18nStore = I18nStore;
exports.I18nStoreContext = I18nStoreContext;
exports.I18nStoreProvider = I18nStoreProvider;
exports.TimePicker = TimePicker;
exports.browserHotkeysConfigs = browserHotkeysConfigs;
exports.createEntityHotkeyConfig = createEntityHotkeyConfig;
exports.editorHotkeysConfigs = editorHotkeysConfigs;
exports.equalsHotkeyConfig = equalsHotkeyConfig;
exports.filterFieldValues = filterFieldValues;
exports.generateKey = generateKey;
exports.guessDisplayName = guessDisplayName;
exports.guessLabel = guessLabel;
exports.menuStore = menuStore;
exports.saveEntityHotkeysConfig = saveEntityHotkeysConfig;
exports.useDefaultBrowserHotkeys = useDefaultBrowserHotkeys;
exports.useDefaultEditorHotkeys = useDefaultEditorHotkeys;
exports.useHotkey = useHotkey;
exports.useHotkeyStore = useHotkeyStore;
exports.useI18nStore = useI18nStore;
exports.useScreenHotkey = useScreenHotkey;
